pipolars.PIQuery
================

.. currentmodule:: pipolars

.. autoclass:: PIQuery

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~PIQuery.__init__
      ~PIQuery.boundary
      ~PIQuery.filter
      ~PIQuery.interpolated
      ~PIQuery.last
      ~PIQuery.limit
      ~PIQuery.pivot
      ~PIQuery.plot
      ~PIQuery.recorded
      ~PIQuery.snapshot
      ~PIQuery.summary
      ~PIQuery.this_month
      ~PIQuery.this_week
      ~PIQuery.time_range
      ~PIQuery.to_dataframe
      ~PIQuery.to_lazy_frame
      ~PIQuery.today
      ~PIQuery.with_quality
      ~PIQuery.without_quality
      ~PIQuery.yesterday
   
   

   
   
   